@@ -8,7 +8,7 @@ PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
 logger = logging.getLogger('aug_sfutils.sfread')
 date_fmt = '%Y-%m-%d'
-#logger.setLevel(logging.DEBUG)
+logger.setLevel(logging.INFO)
 
 def read_other_sf(*args, **kwargs):
 
@@ -114,7 +114,7 @@ def getcti_ts06(nshot):
     except: # shot < 35318
         cdev = cti.getdevice('TS6')
         ts06 = cdev['TRIGGER']
-
+        logger.debug('getcti_ts06 %d', ts06)
     return ts06
 
 
@@ -334,6 +334,7 @@ class SFREAD:
             return None
 
         dfmt = sfo.data_format
+        logger.debug('TB %s %d %d %d', obj, otyp, sfo.length, dfmt)
         if otyp == 8 and sfo.length == 0:
             if sfo.tbase_type == 1: # PPG_prog, e.g. END:T-LM_END
                 dout = self.ppg_time(obj)
@@ -365,7 +366,8 @@ class SFREAD:
 # LongLong in [ns] and no zero at TS06
             if otyp == 8 and dfmt == 13: # RMC:TIME-AD0, SXS:Time
                 logger.debug('Before getts06 dfmt:%d addr:%d len:%d data1:%d, %d', dfmt, addr, bytlen, data[0], data[1])
-                dout = 1e-9*(data - self.getts06())
+                dout = 1e-9*(data - self.getts06(obj))
+                logger.debug('%d',  self.getts06(obj))
             else:
                 dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
 
@@ -509,6 +511,8 @@ class SFREAD:
                 dj0 = 8 * ( (bytlen + 7)//8 )
                 j0 += dj0
 
+            logger.debug('PS %s, PN %s', pset, pname)
+            print(data)
             par_d[pname] = sfobj.SFOBJ(data, sfho=meta)
 
         return par_d
@@ -574,21 +578,21 @@ class SFREAD:
         return self.getparset(lbl)
 
 
-    def getts06(self):
+    def getts06(self, obj):
         """
         Reads the diagnostic internal TS06 from parameter set
         """
         ts6 = 0
-        for obj in self.parsets:
+        for obj in self.getrelnames(obj):
             if self.sfh[obj].obj_type == 3:
                 ps = self.getparset(obj)
                 if 'TS06' in ps.keys():
                     ts6 = ps['TS06']
                     break
 
-        if ts6 == 0:
+        logger.debug('getts06 %s %d', obj, ts6)
+        if ts6 < 1e15:
             ts6 = getcti_ts06(self.shot)
-        logger.debug('getts06 %d', ts6)
         return ts6
 
 
