@@ -1,3 +1,5 @@
+"""Class for shotfiles writing"""
+
 import os, datetime, warnings, logging
 import ctypes as ct
 import numpy as np
@@ -12,7 +14,9 @@ libddww = ct.cdll.LoadLibrary(wwlib)
 
 def getError(error):
 
-    """ Check if an error/warning occured. """
+    """ Check if an error/warning occured
+    """
+
     try:
         err = ct.c_int32(error)
     except TypeError:
@@ -35,9 +39,14 @@ def getError(error):
 
 class WW:
 
+    """py-WW for shotfile writing
+    Wrapper around libddww8.so
+    """
 
     def Open(self, exp, diag, nshot, edition=-1, mode='new'):
-
+        """Equivalent of wwopen
+        Prepares output shotfile.
+        """
         self.Close()
         if nshot > 0:
             date = datetime.date.strftime(datetime.datetime.today(),'%y.%m.%d;%H:%M:%S')
@@ -74,7 +83,9 @@ class WW:
 
 
     def Close(self):
-
+        """Equivalent of wwclose.
+        Terminates the file stream and deletes some attributes
+        """
         if hasattr(self, '_diaref'):
             error = ct.c_int32(0)
             disp  = b'lock'
@@ -94,6 +105,9 @@ class WW:
 
 
     def _wwoinfo(self, signame):
+        """Wrapping wwoinfo_
+        """
+
         if hasattr(self, '_diaref'):
             signame = str_byt.to_byt(signame)
 
@@ -124,7 +138,7 @@ class WW:
 
 
     def GetParameterInfo(self, pset, pnam):
-        """ Returns information about the parameter 'pnam' of the parameter set 'pset'."""
+        """Returns information about the parameter 'pnam' of the parameter set 'pset'."""
 
         if hasattr(self, '_diaref'):
             par_name = str_byt.to_byt(pnam)
@@ -144,6 +158,10 @@ class WW:
 
 
     def SetObject(self, signame, data):
+        """Stores 'data'-array of a given object named 'signame' of type 
+        Signal, SigGroup or Areabase to the target shotfile
+        """
+
         logger.info('Setting %s', signame)
         if hasattr(self, '_diaref'):
             info  = self._wwoinfo(signame)
@@ -157,6 +175,10 @@ class WW:
 
 
     def SetSignal(self, signame, data, indices=None):
+        """Stores 'data'-array of a given Signal named 'signame'
+        to the target shotfile
+        """
+
         if hasattr(self, '_diaref'):
             info  = self._wwoinfo(signame)
             dfmt = info['format']
@@ -238,6 +260,9 @@ class WW:
 
 
     def SetSignalGroup(self, signame, data):
+        """Stores 'data'-array of a given SignalGroup named 'signame'
+        to the target shotfile
+        """
 
         info  = self._wwoinfo(signame)
         dfmt = info['format']
@@ -265,6 +290,9 @@ class WW:
 
 
     def SetAreabase(self, areaname, data):
+        """Stores 'data'-array of a given Areabase named 'areaname'
+        to the target shotfile
+        """
 
         if hasattr(self, '_diaref'):
             info  = self._wwoinfo(areaname)
@@ -310,9 +338,11 @@ class WW:
 
     def SetParameter(self, set_name, par_name, data):
 
-        """ ww.shotfile.SetParameter( SetName , ParameterName , data )\n
-        types: 0 = raw 1 = integer 2 = float 3 = double 4 = complex 5 = logical 6 = character
+        """ ww.shotfile().SetParameter( SetName , ParameterName , data )
+        types: 0=raw 1=integer 2=float 3=double 4=complex 5=logical 6=character
+        The data type is derived from the 00000 shotfile.
         """
+
         if hasattr(self, '_diaref'):
             info = self.GetParameterInfo(set_name, par_name)
             dfmt = info['format']
@@ -383,6 +413,23 @@ class WW:
 
 
 def write_sf(nshot, data_d, sfhdir, diag, exp='AUGD'):
+    """Function for writing a full shotfile from a data dict
+
+    Input:
+        nshot    int   Shotnumber
+        data_d   dict  Dictionary with all relevant objects;
+            Keys are object names - they must match the names in the 00000-SFH
+            Values are object arrays or dictionaries for ParSets. The data
+            types must be the numpy equivalents of the types declared in the
+            00000-SFH.
+            The array sizes (dict values) have to be consistent among them
+            and with the relations in the 00000-SFH, but they do not need
+            to be equal to the ones in the 00000-SFH: if the aren't, 
+            run sfh.Mod* ahead
+        sfhdir   str  Full path of the 00000-SFH
+        diag     str  Diagnostic name
+        exp(opt) str  Exp name
+    """
 
     import os
 
